@@ -1,7 +1,8 @@
 use super::Optimizer;
 use crate::{
-    compress::optimize::util::is_directive,
+    compress::util::is_directive,
     util::{sort::is_sorted_by, MoudleItemExt},
+    DISABLE_BUGGY_PASSES,
 };
 use std::cmp::Ordering;
 use swc_ecma_ast::*;
@@ -28,6 +29,9 @@ impl Optimizer<'_> {
         if !self.options.join_vars {
             return;
         }
+        if DISABLE_BUGGY_PASSES {
+            return;
+        }
 
         // Sort by position
 
